@@ -1,5 +1,6 @@
 library(testthat)
 library(rgeos)
 
-
-test_dir(system.file("tests", package = "rgeos"), StopReporter)#SummaryByContextReporter)
\ No newline at end of file
+set_do_poly_check(FALSE)
+test_dir(system.file("tests", package = "rgeos"), StopReporter)#SummaryByContextReporter)
+set_do_poly_check(TRUE)
